==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-stepper.dart <==
/*
Description:

A widget that dynamically creates a vertical/horizontal stepper for incoming data. The user can pass a list of steps
that are converted to stepper states using length of the array.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-stepper.dart';

Usage:
The user passes a List of CustomSteps that define the different steps in a Stepper.
The user can also define different functionality and parameters using the StepperParameter class.
Moreover, the user can provide custom definition for Cancel, Tap and Continue Stepper actions.

- Defining the elements for Stepper
	List<CustomSteps> steps = [
      CustomSteps(
          title: Text('First Name'),
          subtitle: Text('Please enter your first name'),
          content: TextField(),
          isActive: true),
      CustomSteps(
          title: Text('Last Name'),
          subtitle: Text('Please enter your last name'),
          content: TextField(),
          isActive: true)
    ];

    StepperParameters stepperParams =
        new StepperParameters(type: StepperType.vertical);

    onStepperComplete() {
      print('Complete');
    }

- Object call for the widget
  CustomStepper(steps, stepperParams, null, null, null, onStepperComplete)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';

class CustomStepper extends StatefulWidget {
  List<CustomSteps> steps;
  StepperParameters stepperParams;
  Function(int, String) onTapped;
  Function(int, String) onContinue;
  Function(int, String) onCancel;
  Function() onSubmit;
  CustomStepper(this.steps, this.stepperParams, this.onTapped, this.onContinue,
      this.onCancel, this.onSubmit);

  @override
  _customStepper createState() => new _customStepper(
      this.steps,
      this.stepperParams,
      this.onTapped,
      this.onContinue,
      this.onCancel,
      this.onSubmit);
}

class _customStepper extends State<CustomStepper> {
  List<CustomSteps> steps;
  StepperParameters stepperParams;
  Function(int, String) onTapped;
  Function(int, String) onContinue;
  Function(int, String) onCancel;
  Function() onSubmit;
  _customStepper(this.steps, this.stepperParams, this.onTapped, this.onContinue,
      this.onCancel, this.onSubmit);

  int currentStep;
  bool complete;
  List<StepState> listState;

  @override
  void initState() {
    currentStep = 0;
    complete = false;
    listState = [
      StepState.indexed,
      StepState.editing,
      StepState.complete,
      StepState.disabled,
      StepState.error,
    ];
    super.initState();
  }

  List<Step> _createSteps(BuildContext context) {
    List<Step> stepArray = [];
    if (steps != null && steps.length != 0) {
      for (int step = 0; step < steps.length; step++) {
        stepArray.add(Step(
            title: (steps[step].title != null)
                ? steps[step].title
                : Text(cons.sampleText),
            subtitle: (steps[step].subtitle != null)
                ? steps[step].subtitle
                : Text(cons.sampleText),
            content: (steps[step].content != null)
                ? steps[step].content
                : IconButton(icon: Icon(cons.icon1)),
            state: (steps[step].state != null)
                ? steps[step].state
                : currentStep == step
                    ? listState[1]
                    : currentStep > step ? listState[2] : listState[0],
            isActive: (steps[step].isActive != null)
                ? steps[step].isActive
                : currentStep == step ? true : false));
      }
    } else {
      Step step1 = new Step(
          title: Text(cons.listTitle),
          subtitle: Text(cons.listSubtitle),
          content: IconButton(
            icon: Icon(Icons.add_alarm),
            onPressed: () {},
          ),
          state: currentStep == 0
              ? listState[1]
              : currentStep > 0 ? listState[2] : listState[0],
          isActive: currentStep == 0 ? true : false);

      Step step2 = new Step(
          title: Text(cons.listTitle),
          subtitle: Text(cons.listSubtitle),
          content: IconButton(
            icon: Icon(Icons.add_alarm),
            onPressed: () {},
          ),
          state: currentStep == 1
              ? listState[1]
              : currentStep > 0 ? listState[2] : listState[0],
          isActive: currentStep == 1 ? true : false);
      stepArray.add(step1);
      stepArray.add(step2);
    }
    return stepArray;
  }

  @override
  Widget build(BuildContext context) {
    List<Step> stepArray = _createSteps(context);

    goTo(int step) {
      setState(() => currentStep = step);
    }

    defaultNext() {
      setState(() {
        if (currentStep < stepArray.length - 1) {
          currentStep = currentStep + 1;
        } else {
          currentStep = stepArray.length - 1;
          complete = true;
          if (complete) {
            onSubmit();
          }
        }
      });
    }

    defaultCancel() {
      setState(() {
        if (currentStep > 0) {
          currentStep--;
        } else {
          currentStep = 0;
        }
        //_setStep(context);
      });
    }

    if (stepperParams != null) {
      return Scaffold(
        body: Column(
          children: <Widget>[
            Expanded(
              child: Stepper(
                steps: stepArray,
                currentStep: currentStep < stepArray.length ? currentStep : 0,
                type: (stepperParams.type != null)
                    ? stepperParams.type
                    : StepperType.vertical,
                onStepContinue: (onContinue != null) ? onContinue : defaultNext,
                onStepTapped:
                    (onTapped != null) ? onTapped : (step) => goTo(step),
                onStepCancel: (onCancel != null) ? onCancel : defaultCancel,
              ),
            )
          ],
        ),
      );
    } else {
      return Scaffold(
        body: Column(
          children: <Widget>[
            Expanded(
              child: Stepper(
                steps: stepArray,
                currentStep: 0,
                type: StepperType.vertical,
                onStepContinue: defaultNext,
                onStepTapped: (step) => goTo(step),
                onStepCancel: defaultCancel,
              ),
            )
          ],
        ),
      );
    }
  }
}

==> flutter_catalogue_widgets-0.0.7.tar.gz: lib/custom-stepper.dart <==
/*
Description:

A widget that dynamically creates a vertical/horizontal stepper for incoming data. The user can pass a list of steps
that are converted to stepper states using length of the array.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-stepper.dart';

Usage:
The user passes a List of CustomSteps that define the different steps in a Stepper.
The user can also define different functionality and parameters using the StepperParameter class.
Moreover, the user can provide custom definition for Cancel, Tap and Continue Stepper actions.

- Defining the elements for Stepper
	List<CustomSteps> steps = [
      CustomSteps(
          title: Text('First Name'),
          subtitle: Text('Please enter your first name'),
          content: TextField(),
          isActive: true),
      CustomSteps(
          title: Text('Last Name'),
          subtitle: Text('Please enter your last name'),
          content: TextField(),
          isActive: true)
    ];

    StepperParameters stepperparams =
        new StepperParameters(type: StepperType.vertical);

    onStepperComplete() {
      print('Complete');
    }

- Object call for the widget
  CustomStepper(steps, stepperparams, null, null, null, onStepperComplete)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';

class CustomStepper extends StatefulWidget {
  List<CustomSteps> steps;
  StepperParameters stepperparams;
  Function(int, String) onTapped;
  Function(int, String) onContinue;
  Function(int, String) onCancel;
  Function() onSubmit;
  CustomStepper(this.steps, this.stepperparams, this.onTapped, this.onContinue,
      this.onCancel, this.onSubmit);

  @override
  _CustomStepper createState() => new _CustomStepper(
      this.steps,
      this.stepperparams,
      this.onTapped,
      this.onContinue,
      this.onCancel,
      this.onSubmit);
}

class _CustomStepper extends State<CustomStepper> {
  List<CustomSteps> steps;
  StepperParameters stepperparams;
  Function(int, String) onTapped;
  Function(int, String) onContinue;
  Function(int, String) onCancel;
  Function() onSubmit;
  _CustomStepper(this.steps, this.stepperparams, this.onTapped, this.onContinue,
      this.onCancel, this.onSubmit);

  int currentStep;
  bool complete;
  List<StepState> listState;

  @override
  void initState() {
    currentStep = 0;
    complete = false;
    listState = [
      StepState.indexed,
      StepState.editing,
      StepState.complete,
      StepState.disabled,
      StepState.error,
    ];
    super.initState();
  }

  List<Step> _createSteps(BuildContext context) {
    List<Step> stepArray = [];
    if (steps != null && steps.length != 0) {
      for (int step = 0; step < steps.length; step++) {
        stepArray.add(Step(
            title: (steps[step].title != null)
                ? steps[step].title
                : Text(cons.sampleText),
            subtitle: (steps[step].subtitle != null)
                ? steps[step].subtitle
                : Text(cons.sampleText),
            content: (steps[step].content != null)
                ? steps[step].content
                : IconButton(icon: Icon(cons.icon1)),
            state: (steps[step].state != null)
                ? steps[step].state
                : currentStep == step
                    ? listState[1]
                    : currentStep > step ? listState[2] : listState[0],
            isActive: (steps[step].isActive != null)
                ? steps[step].isActive
                : currentStep == step ? true : false));
      }
    } else {
      Step step1 = new Step(
          title: Text(cons.listTitle),
          subtitle: Text(cons.listSubtitle),
          content: IconButton(
            icon: Icon(Icons.add_alarm),
            onPressed: () {},
          ),
          state: currentStep == 0
              ? listState[1]
              : currentStep > 0 ? listState[2] : listState[0],
          isActive: currentStep == 0 ? true : false);

      Step step2 = new Step(
          title: Text(cons.listTitle),
          subtitle: Text(cons.listSubtitle),
          content: IconButton(
            icon: Icon(Icons.add_alarm),
            onPressed: () {},
          ),
          state: currentStep == 1
              ? listState[1]
              : currentStep > 0 ? listState[2] : listState[0],
          isActive: currentStep == 1 ? true : false);
      stepArray.add(step1);
      stepArray.add(step2);
    }
    return stepArray;
  }

  @override
  Widget build(BuildContext context) {
    List<Step> stepArray = _createSteps(context);

    goTo(int step) {
      setState(() => currentStep = step);
    }

    defaultNext() {
      setState(() {
        if (currentStep < stepArray.length - 1) {
          currentStep = currentStep + 1;
        } else {
          currentStep = stepArray.length - 1;
          complete = true;
          if (complete) {
            onSubmit();
          }
        }
      });
    }

    defaultCancel() {
      setState(() {
        if (currentStep > 0) {
          currentStep--;
        } else {
          currentStep = 0;
        }
        //_setStep(context);
      });
    }

    if (stepperparams != null) {
      return Scaffold(
        body: Column(
          children: <Widget>[
            Expanded(
              child: Stepper(
                steps: stepArray,
                currentStep: currentStep < stepArray.length ? currentStep : 0,
                type: (stepperparams.type != null)
                    ? stepperparams.type
                    : StepperType.vertical,
                onStepContinue: (onContinue != null) ? onContinue : defaultNext,
                onStepTapped:
                    (onTapped != null) ? onTapped : (step) => goTo(step),
                onStepCancel: (onCancel != null) ? onCancel : defaultCancel,
              ),
            )
          ],
        ),
      );
    } else {
      return Scaffold(
        body: Column(
          children: <Widget>[
            Expanded(
              child: Stepper(
                steps: stepArray,
                currentStep: 0,
                type: StepperType.vertical,
                onStepContinue: defaultNext,
                onStepTapped: (step) => goTo(step),
                onStepCancel: defaultCancel,
              ),
            )
          ],
        ),
      );
    }
  }
}
